# Certbot DNS Plugin for Hostinger

Welcome to the documentation for the Certbot DNS plugin for Hostinger.

This plugin allows you to use Certbot with Hostinger DNS for automated SSL certificate generation using DNS-01 challenges.

## Contents

- [Installation](installation.md)
- [Usage](usage.md)
- [Configuration](configuration.md)
- [Troubleshooting](troubleshooting.md)

## Indices and tables

- [Index](genindex.md)
- [Module Index](modindex.md)
- [Search](search.md)
